@@ -50,6 +50,10 @@ class SQLServer2DatacatalogCli(datacatalog_cli.DatacatalogCli):
         return os.path.join(os.path.dirname(os.path.abspath(__file__)),
                             'config/metadata_query.sql')
 
+    def _get_connector_config_path(self):
+        return os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                            'config')
+
     def _parse_args(self, argv):
         parser = argparse.ArgumentParser(
             description='Command line to sync sqlserver '
@@ -65,6 +69,9 @@ class SQLServer2DatacatalogCli(datacatalog_cli.DatacatalogCli):
         parser.add_argument('--datacatalog-entry-group-id',
                             help='Entry group ID to be used for your Google '
                             'Cloud Datacatalog')
+        parser.add_argument('--datacatalog-entry-resource-url-prefix',
+                            help='Entry resource URL prefix '
+                            'used in the ingested Data Catalog Entries')
         parser.add_argument(
             '--sqlserver-host',
             help='Your sqlserver server host, this is required even'
